"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TDengineDatabaseService = void 0;
const axios_1 = require("@nestjs/axios");
const common_1 = require("@nestjs/common");
const rxjs_1 = require("rxjs");
const error_wrapper_decorator_1 = require("../decorators/error-wrapper.decorator");
const database_util_1 = require("../utils/database.util");
let TDengineDatabaseService = class TDengineDatabaseService {
    constructor(httpService, databaseUtil) {
        this.httpService = httpService;
        this.databaseUtil = databaseUtil;
    }
    /**
     * 创建TDengine数据库
     * @param database 数据库名称
     * @param keep 数据保留时间，单位：天，默认：10年
     * @param ifNotExists 是否仅不存在的时候创建，默认为：否
     * @returns 创建结果
     */
    async create(database, keep = 365 * 10, ifNotExists = false) {
        const sql = `CREATE DATABASE ${ifNotExists ? 'IF NOT EXISTS' : ''} ${database} KEEP ${keep}`;
        const { data } = await rxjs_1.firstValueFrom(this.httpService.post('/rest/sql', sql));
        return { success: data.status === "succ" /* Success */ };
    }
    /**
     * 删除TDengine数据库
     * @param database 数据库名称
     * @param ifExists 是否仅存在的时候删除，默认为：否
     * @returns 删除结果
     */
    async delete(database, ifExists = false) {
        const sql = `DROP DATABASE ${ifExists ? 'IF EXISTS' : ''} ${database}`;
        const { data } = await rxjs_1.firstValueFrom(this.httpService.post('/rest/sql', sql));
        return { success: data.status === "succ" /* Success */ };
    }
    /**
     * 获取TDengine中所有的数据库列表
     * @returns TDengine 数据库列表
     */
    async getAll() {
        const { data } = await rxjs_1.firstValueFrom(this.httpService.post('/rest/sql', `SHOW DATABASES`));
        const databaseList = this.databaseUtil.resolveDatabaseInfoList(data);
        return { success: data.status === "succ" /* Success */, data: databaseList };
    }
};
__decorate([
    error_wrapper_decorator_1.TDengineErrorWrapper(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object, Object]),
    __metadata("design:returntype", Promise)
], TDengineDatabaseService.prototype, "create", null);
__decorate([
    error_wrapper_decorator_1.TDengineErrorWrapper(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object]),
    __metadata("design:returntype", Promise)
], TDengineDatabaseService.prototype, "delete", null);
__decorate([
    error_wrapper_decorator_1.TDengineErrorWrapper(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], TDengineDatabaseService.prototype, "getAll", null);
TDengineDatabaseService = __decorate([
    common_1.Injectable(),
    __metadata("design:paramtypes", [axios_1.HttpService, database_util_1.DatabaseUtil])
], TDengineDatabaseService);
exports.TDengineDatabaseService = TDengineDatabaseService;
